==> huaweicloudsdkcdn-3.1.75-py2.py3-none-any.whl: huaweicloudsdkcdn/v1/model/referer_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class RefererBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'referer': 'Referer'
    }

    attribute_map = {
        'referer': 'referer'
    }

    def __init__(self, referer=None):
        """RefererBody

        The model defined in huaweicloud sdk

        :param referer: 
        :type referer: :class:`huaweicloudsdkcdn.v1.Referer`
        """
        
        

        self._referer = None
        self.discriminator = None

        self.referer = referer

    @property
    def referer(self):
        """Gets the referer of this RefererBody.

        :return: The referer of this RefererBody.
        :rtype: :class:`huaweicloudsdkcdn.v1.Referer`
        """
        return self._referer

    @referer.setter
    def referer(self, referer):
        """Sets the referer of this RefererBody.

        :param referer: The referer of this RefererBody.
        :type referer: :class:`huaweicloudsdkcdn.v1.Referer`
        """
        self._referer = referer

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RefererBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcdn-3.1.158-py2.py3-none-any.whl: huaweicloudsdkcdn/v1/model/referer_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class RefererBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'referer': 'Referer'
    }

    attribute_map = {
        'referer': 'referer'
    }

    def __init__(self, referer=None):
        r"""RefererBody

        The model defined in huaweicloud sdk

        :param referer: 
        :type referer: :class:`huaweicloudsdkcdn.v1.Referer`
        """
        
        

        self._referer = None
        self.discriminator = None

        self.referer = referer

    @property
    def referer(self):
        r"""Gets the referer of this RefererBody.

        :return: The referer of this RefererBody.
        :rtype: :class:`huaweicloudsdkcdn.v1.Referer`
        """
        return self._referer

    @referer.setter
    def referer(self, referer):
        r"""Sets the referer of this RefererBody.

        :param referer: The referer of this RefererBody.
        :type referer: :class:`huaweicloudsdkcdn.v1.Referer`
        """
        self._referer = referer

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RefererBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
